ModulePeerData

Struct ModulePeerData 

pub struct ModulePeerData(/* private fields */);
A struct containing data of a peer for multiple signaling modules, each associated with the module’s namespace.

Implementations

Source

impl ModulePeerData

pub fn new() -> ModulePeerData

Create a new empty ModulePeerData.

pub fn get<T>(&self) -> Result<Option<T>, Error>

Get the peer frontend data for a specific module

pub fn insert<T>(&mut self, data: &T) -> Result<(), Error>

Set the peer frontend data for a specific module

If an entry with the namespace already exists, it will be overwritten. If the namespace of T is None, the data will not be stored at all.

pub fn update<T, F>(&mut self, update: F) -> Result<Option<T>, Error>

Updates the module data and returns the new data

pub fn contains_key(&self, key: &ModuleId) -> bool

Query whether the module data contains a value for this key

pub fn remove<T>(&mut self)

Remove an entry by the namespace of SignalingModulePeerFrontendData type.

This method does not verify that the data actually can be deserialized into the requested types, it just uses its namespace and removes an entry with that namespace if it exists.

pub fn remove_key(&mut self, key: &ModuleId)

Remove an entry by its key if it exists.

pub fn take<T>(&mut self) -> Result<Option<T>, Error>

Take an entry by the namespace of a type.

If the entry is present but can not be deserialized into the requested type, the data will remain unchanged, the entry is not removed.