SignalingModulePeerFrontendData

Trait SignalingModulePeerFrontendData 

pub trait SignalingModulePeerFrontendData:
    Serialize
    + DeserializeOwned
    + Debug {
    const NAMESPACE: Option<ModuleId>;
}
A trait for defining data for peers sent to the frontend of a signaling module.

Required Associated Constants

const NAMESPACE: Option<ModuleId>

The namespace which is used to tag the signaling module participant data

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl SignalingModulePeerFrontendData for WaitingRoomState

Available on crate feature serde only.
Source

impl SignalingModulePeerFrontendData for ()

Source

impl SignalingModulePeerFrontendData for ChatPeerState

Available on crate feature serde only.
Source

impl SignalingModulePeerFrontendData for ControlState

Available on crate feature serde only.
Source

impl SignalingModulePeerFrontendData for MeetingNotesPeerState

Available on crate feature serde only.
Source

impl SignalingModulePeerFrontendData for RecordingPeerState

Available on crate feature serde only.
Source

impl SignalingModulePeerFrontendData for TimerPeerState

Available on crate feature serde only.

Implementors