pub struct ModulePeerData(/* private fields */);Expand description
A struct containing data of a peer for multiple signaling modules, each associated with the module’s namespace.
Implementations
Sourceimpl ModulePeerData
impl ModulePeerData
Sourcepub fn new() -> ModulePeerData
pub fn new() -> ModulePeerData
Create a new empty ModulePeerData.
Sourcepub fn get<T>(&self) -> Result<Option<T>, Error>where
T: SignalingModulePeerFrontendData,
pub fn get<T>(&self) -> Result<Option<T>, Error>where
T: SignalingModulePeerFrontendData,
Get the peer frontend data for a specific module
Sourcepub fn insert<T>(&mut self, data: &T) -> Result<(), Error>where
T: SignalingModulePeerFrontendData,
pub fn insert<T>(&mut self, data: &T) -> Result<(), Error>where
T: SignalingModulePeerFrontendData,
Set the peer frontend data for a specific module
If an entry with the namespace already exists, it will be overwritten.
If the namespace of T is None, the data will not be stored at all.
Sourcepub fn update<T, F>(&mut self, update: F) -> Result<Option<T>, Error>
pub fn update<T, F>(&mut self, update: F) -> Result<Option<T>, Error>
Updates the module data and returns the new data
Sourcepub fn contains_key(&self, key: &ModuleId) -> bool
pub fn contains_key(&self, key: &ModuleId) -> bool
Query whether the module data contains a value for this key
Sourcepub fn remove<T>(&mut self)where
T: SignalingModulePeerFrontendData,
pub fn remove<T>(&mut self)where
T: SignalingModulePeerFrontendData,
Remove an entry by the namespace of SignalingModulePeerFrontendData type.
This method does not verify that the data actually can be deserialized into the requested types, it just uses its namespace and removes an entry with that namespace if it exists.
Sourcepub fn remove_key(&mut self, key: &ModuleId)
pub fn remove_key(&mut self, key: &ModuleId)
Remove an entry by its key if it exists.